@@ -20,11 +20,23 @@
 // Code for SWIG tests of the LALDetChar bindings.
 // Author: Karl Wette
 
-// Include LAL test code header.
 #include <lal/SWIGLALTest.h>
 
+#ifndef _SWIGLALDETCHARTEST_H
+#define _SWIGLALDETCHARTEST_H
+
+#ifdef  __cplusplus
+extern "C" {
+#endif
+
 // Test object parent tracking between modules.
 typedef struct tagswig_laldetchar_test_parent_map_struct {
   swig_lal_test_struct s;
 } swig_laldetchar_test_parent_map_struct;
-swig_laldetchar_test_parent_map_struct swig_laldetchar_test_parent_map;
+extern swig_laldetchar_test_parent_map_struct swig_laldetchar_test_parent_map;
+
+#ifdef __cplusplus
+}
+#endif
+
+#endif // _SWIGLALDETCHARTEST_H
